==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24StyledViewFactory.c <==
// class javax.swing.text.StyledEditorKit$StyledViewFactory

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 8736ce015aeffaf5 javax_swing_text_Element
// @dep_class 89039d3a7c79ae9a javax_swing_text_StyledEditorKit
// @dep_class 1a33bf2d417a6521 javax_swing_text_StyledEditorKit__24StyledViewFactory
// @dep_class b564f56d2f2041c1 javax_swing_text_View
// @dep_class e140620ddc1d6a0f javax_swing_text_ViewFactory

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_text_Element
// @dep_header javax_swing_text_StyledEditorKit
// @dep_header javax_swing_text_StyledEditorKit__24StyledViewFactory
// @dep_header javax_swing_text_View
// @dep_header javax_swing_text_ViewFactory

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/text/Element.h"
#include "javax/swing/text/StyledEditorKit.h"
#include "javax/swing/text/StyledEditorKit__24StyledViewFactory.h"
#include "javax/swing/text/View.h"
#include "javax/swing/text/ViewFactory.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_StyledEditorKit__24StyledViewFactory, _init$52f4ad9f2989aeee);

void
_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *this)
{
	struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(341);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.swing.text.View create(javax.swing.text.Element)
//

static _jc_linenum _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$create$cf4235120765a02e[];

static const unsigned char _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$create$cf4235120765a02e[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_types$create$cf4235120765a02e[] = {
	&_jc_javax_swing_text_Element$type
};

_jc_method _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e = {
	.name=			"create",
	.signature=		"(Ljavax/swing/text/Element;)Ljavax/swing/text/View;",
	.class=			&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type,
	.param_types=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_types$create$cf4235120765a02e,
	.return_type=		&_jc_javax_swing_text_View$type,
	.param_ptypes=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$create$cf4235120765a02e,
	.signature_hash=	_JC_JLONG(0xcf4235120765a02e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable, javax_swing_text_StyledEditorKit__24StyledViewFactory.create$cf4235120765a02e) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$create$cf4235120765a02e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_StyledEditorKit__24StyledViewFactory, create$cf4235120765a02e);

_jc_javax_swing_text_View$object *
_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e(_jc_env *const env, _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *this, _jc_object *param0)
{
	struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(350);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods[] = {
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces[] = {
	&_jc_javax_swing_text_ViewFactory$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_bucket_46[] = {
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[46]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_bucket_46
};

// Interface "quick" lookup hash table
static const void *_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[46]=	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_15[] = {
	&_jc_javax_swing_text_ViewFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_33[] = {
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[15]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_15,
	[33]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_33,
	[113]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/text/Element",	_JC_JLONG(0x8736ce015aeffaf5) },
	{ "javax/swing/text/StyledEditorKit",	_JC_JLONG(0x89039d3a7c79ae9a) },
	{ "javax/swing/text/View",	_JC_JLONG(0xb564f56d2f2041c1) },
	{ "javax/swing/text/ViewFactory",	_JC_JLONG(0xe140620ddc1d6a0f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type = {
    .type= {
	.name=			"javax/swing/text/StyledEditorKit$StyledViewFactory",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces) / sizeof(*_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces),
	.interfaces=		_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces,
	.imethod_hash_table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_table,
	.imethod_quick_table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x1a33bf2d417a6521),
		.source_file=		"StyledEditorKit.java",
		.instance_size=		sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs) + sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods) / sizeof(*_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods),
		.methods=		_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods,
		.instanceof_hash_table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_text_StyledEditorKit$type,
		.num_class_depends=		sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends) / sizeof(*_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends),
		.class_depends=		_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_text_StyledEditorKit__24StyledViewFactory= {
	    .create$cf4235120765a02e=
		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit__24StyledViewFactory.c <==
// class javax.swing.text.StyledEditorKit$StyledViewFactory

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 8736ce015aeffaf5 javax_swing_text_Element
// @dep_class 89039d3a7c79ae9a javax_swing_text_StyledEditorKit
// @dep_class 1a33bf2d417a6521 javax_swing_text_StyledEditorKit__24StyledViewFactory
// @dep_class b564f56d2f2041c1 javax_swing_text_View
// @dep_class e140620ddc1d6a0f javax_swing_text_ViewFactory

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_text_Element
// @dep_header javax_swing_text_StyledEditorKit
// @dep_header javax_swing_text_StyledEditorKit__24StyledViewFactory
// @dep_header javax_swing_text_View
// @dep_header javax_swing_text_ViewFactory

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/text/Element.h"
#include "javax/swing/text/StyledEditorKit.h"
#include "javax/swing/text/StyledEditorKit__24StyledViewFactory.h"
#include "javax/swing/text/View.h"
#include "javax/swing/text/ViewFactory.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_StyledEditorKit__24StyledViewFactory, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *this)
{
	struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(341);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.swing.text.View create(javax.swing.text.Element)
//

static _jc_linenum _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$create$cf4235120765a02e[];

static const unsigned char _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$create$cf4235120765a02e[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_types$create$cf4235120765a02e[] = {
	&_jc_javax_swing_text_Element$type
};

_jc_method _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e = {
	.name=			"create",
	.signature=		"(Ljavax/swing/text/Element;)Ljavax/swing/text/View;",
	.class=			&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type,
	.param_types=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_types$create$cf4235120765a02e,
	.return_type=		&_jc_javax_swing_text_View$type,
	.param_ptypes=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$param_ptypes$create$cf4235120765a02e,
	.signature_hash=	_JC_JLONG(0xcf4235120765a02e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtable, javax_swing_text_StyledEditorKit__24StyledViewFactory.create$cf4235120765a02e) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$linenum_table$create$cf4235120765a02e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_text_StyledEditorKit__24StyledViewFactory, create$cf4235120765a02e);

_jc_javax_swing_text_View$object * _JC_JCNI_ATTR
_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e(_jc_env *const env, _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *this, _jc_object *param0)
{
	struct _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(350);				// 0
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods[] = {
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces[] = {
	&_jc_javax_swing_text_ViewFactory$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_bucket_46[] = {
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method_info$create$cf4235120765a02e,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[46]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_bucket_46
};

// Interface "quick" lookup hash table
static const void *_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[46]=	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_15[] = {
	&_jc_javax_swing_text_ViewFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_33[] = {
	&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[15]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_15,
	[33]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_33,
	[101]=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/text/Element",	_JC_JLONG(0x8736ce015aeffaf5) },
	{ "javax/swing/text/StyledEditorKit",	_JC_JLONG(0x89039d3a7c79ae9a) },
	{ "javax/swing/text/View",	_JC_JLONG(0xb564f56d2f2041c1) },
	{ "javax/swing/text/ViewFactory",	_JC_JLONG(0xe140620ddc1d6a0f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$vtype _jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$type = {
    .type= {
	.name=			"javax/swing/text/StyledEditorKit$StyledViewFactory",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces) / sizeof(*_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces),
	.interfaces=		_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$interfaces,
	.imethod_hash_table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_hash_table,
	.imethod_quick_table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x1a33bf2d417a6521),
		.source_file=		"StyledEditorKit.java",
		.instance_size=		sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$refs) + sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods) / sizeof(*_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods),
		.methods=		_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$methods,
		.instanceof_hash_table=	_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_text_StyledEditorKit$type,
		.num_class_depends=		sizeof(_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends) / sizeof(*_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends),
		.class_depends=		_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_text_StyledEditorKit__24StyledViewFactory= {
	    .create$cf4235120765a02e=
		&_jc_javax_swing_text_StyledEditorKit__24StyledViewFactory$method$create$cf4235120765a02e,
	},
    }
};
